@@ -273,7 +273,6 @@ with section("parse"):
                 "flags": [
                     "EXCLUDE_FROM_ALL",
                     "EXCLUDE_FROM_DEFAULT_BUILD",
-                    "AUTOGLOB",
                     "INTERNAL_FLAGS",
                     "NOLIBS",
                 ],
@@ -321,7 +320,6 @@ with section("parse"):
                     "INTERNAL_FLAGS",
                     "NOLIBS",
                     "NOEXPORT",
-                    "AUTOGLOB",
                     "STATIC",
                     "NONAMEPREFIX",
                 ],
@@ -382,7 +380,7 @@ with section("parse"):
             "kwargs": {
                 "ARGS": "+",
                 "EXECUTABLE": 1,
-                "LOCALITIES": 1,
+                "RANKS": 1,
             },
             "pargs": {"flags": ["FAILURE_EXPECTED"], "nargs": "2+"},
         },
