@@ -82,23 +82,19 @@ int pika_main(variables_map& vm)
 {
     std::size_t pikathread_count = 0;
 
-    if (vm.count("pikathreads"))
-        pikathread_count = vm["pikathreads"].as<std::size_t>();
+    if (vm.count("pikathreads")) pikathread_count = vm["pikathreads"].as<std::size_t>();
 
     std::size_t mutex_count = 0;
 
-    if (vm.count("mutexes"))
-        mutex_count = vm["mutexes"].as<std::size_t>();
+    if (vm.count("mutexes")) mutex_count = vm["mutexes"].as<std::size_t>();
 
     std::size_t iterations = 0;
 
-    if (vm.count("iterations"))
-        iterations = vm["iterations"].as<std::size_t>();
+    if (vm.count("iterations")) iterations = vm["iterations"].as<std::size_t>();
 
     std::size_t wait = 0;
 
-    if (vm.count("wait"))
-        wait = vm["wait"].as<std::size_t>();
+    if (vm.count("wait")) wait = vm["wait"].as<std::size_t>();
 
     for (std::size_t i = 0; i < iterations; ++i)
     {
