@@ -4,17 +4,23 @@
 //  Distributed under the Boost Software License, Version 1.0. (See accompanying
 //  file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
-#include <pika/future.hpp>
+#include <pika/execution.hpp>
+#include <pika/functional/bind_front.hpp>
 #include <pika/init.hpp>
+#include <pika/latch.hpp>
 #include <pika/thread.hpp>
 
+#include <cstdlib>
 #include <functional>
 #include <iostream>
+#include <utility>
 #include <vector>
 
+namespace ex = pika::execution::experimental;
+namespace tt = pika::this_thread::experimental;
+
 int const num_threads = 10;
 
-///////////////////////////////////////////////////////////////////////////////
 void wait_for_latch(pika::latch& l) { l.arrive_and_wait(); }
 
 int pika_main()
@@ -22,11 +28,15 @@ int pika_main()
     // Spawn a couple of threads
     pika::latch l(num_threads + 1);
 
-    std::vector<pika::future<void>> results;
+    std::vector<ex::unique_any_sender<>> results;
     results.reserve(num_threads);
 
     for (int i = 0; i != num_threads; ++i)
-        results.push_back(pika::async(&wait_for_latch, std::ref(l)));
+    {
+        results.push_back(ex::schedule(ex::thread_pool_scheduler{}) |
+            ex::then(pika::util::detail::bind_front(wait_for_latch, std::ref(l))) |
+            ex::ensure_started());
+    }
 
     // Allow spawned threads to reach latch
     pika::this_thread::yield();
@@ -45,9 +55,10 @@ int pika_main()
     // Wait for all threads to reach this point.
     l.arrive_and_wait();
 
-    pika::wait_all(results);
+    tt::sync_wait(ex::when_all_vector(std::move(results)));
 
-    return pika::finalize();
+    pika::finalize();
+    return EXIT_SUCCESS;
 }
 
 int main(int argc, char* argv[]) { return pika::init(pika_main, argc, argv); }
