@@ -204,8 +204,8 @@ namespace pika::cuda::experimental {
                         PIKA_FORWARD(Receiver, receiver), s.f, s.sched});
             }
 
-            friend auto tag_invoke(
-                pika::execution::experimental::get_env_t, then_on_host_sender_type const& s)
+            friend auto tag_invoke(pika::execution::experimental::get_env_t,
+                then_on_host_sender_type const& s) noexcept
             {
                 return pika::execution::experimental::get_env(s.sender);
             }
