@@ -7,7 +7,7 @@
 #include <pika/modules/execution.hpp>
 #include <pika/testing.hpp>
 
-#include "algorithm_test_utils.hpp"
+#include <pika/execution_base/tests/algorithm_test_utils.hpp>
 
 #include <atomic>
 #include <exception>
@@ -27,10 +27,7 @@ struct custom_transformer
     void operator()() const
     {
         call_operator_called = true;
-        if (throws)
-        {
-            throw std::runtime_error("error");
-        }
+        if (throws) { throw std::runtime_error("error"); }
     }
 };
 
