@@ -15,6 +15,7 @@
 #include <atomic>
 #include <chrono>
 #include <cstddef>
+#include <cstdlib>
 #include <exception>
 #include <stdexcept>
 #include <string>
@@ -734,199 +735,6 @@ void test_when_all_vector()
     }
 }
 
-void test_future_sender()
-{
-    // futures as senders
-    {
-        std::atomic<bool> called{false};
-        auto f = pika::async([&]() { called = true; });
-
-        static_assert(ex::is_sender_v<std::decay_t<decltype(f)>>, "a future should be a sender");
-        static_assert(std::is_void<decltype(tt::sync_wait(std::move(f)))>::value,
-            "sync_wait should return void");
-
-        tt::sync_wait(std::move(f));
-        PIKA_TEST(called);
-
-        bool exception_thrown = false;
-        try
-        {
-            // The move is intentional. sync_wait should throw.
-            // NOLINTNEXTLINE(bugprone-use-after-move)
-            tt::sync_wait(std::move(f));
-            PIKA_TEST(false);
-        }
-        catch (...)
-        {
-            exception_thrown = true;
-        }
-        PIKA_TEST(exception_thrown);
-    }
-
-    {
-        std::atomic<bool> called{false};
-        auto f = pika::async([&]() {
-            called = true;
-            return 42;
-        });
-
-        static_assert(ex::is_sender_v<std::decay_t<decltype(f)>>, "a future should be a sender");
-
-        PIKA_TEST_EQ(tt::sync_wait(std::move(f)), 42);
-        PIKA_TEST(called);
-
-        bool exception_thrown = false;
-        try
-        {
-            // The move is intentional. sync_wait should throw.
-            // NOLINTNEXTLINE(bugprone-use-after-move)
-            tt::sync_wait(std::move(f));
-            PIKA_TEST(false);
-        }
-        catch (...)
-        {
-            exception_thrown = true;
-        }
-        PIKA_TEST(exception_thrown);
-    }
-
-    {
-        std::atomic<bool> called{false};
-        auto f = pika::async([&]() {
-            called = true;
-            return 42;
-        });
-
-        PIKA_TEST_EQ(tt::sync_wait(ex::then(std::move(f), [](int x) { return x / 2; })), 21);
-        PIKA_TEST(called);
-    }
-
-    {
-        std::atomic<std::size_t> calls{0};
-        auto sf = pika::async([&]() { ++calls; }).share();
-
-        static_assert(
-            ex::is_sender_v<std::decay_t<decltype(sf)>>, "a shared_future should be a sender");
-        static_assert(std::is_void<decltype(tt::sync_wait(std::move(sf)))>::value,
-            "sync_wait should return void");
-
-        tt::sync_wait(sf);
-        tt::sync_wait(sf);
-        tt::sync_wait(std::move(sf));
-        PIKA_TEST_EQ(calls.load(), std::size_t(1));
-
-        bool exception_thrown = false;
-        try
-        {
-            tt::sync_wait(sf);
-            PIKA_TEST(false);
-        }
-        catch (...)
-        {
-            exception_thrown = true;
-        }
-        PIKA_TEST(exception_thrown);
-    }
-
-    {
-        std::atomic<std::size_t> calls{0};
-        auto sf = pika::async([&]() {
-            ++calls;
-            return 42;
-        }).share();
-
-        static_assert(
-            ex::is_sender_v<std::decay_t<decltype(sf)>>, "a shared_future should be a sender");
-
-        PIKA_TEST_EQ(tt::sync_wait(sf), 42);
-        PIKA_TEST_EQ(tt::sync_wait(sf), 42);
-        PIKA_TEST_EQ(tt::sync_wait(std::move(sf)), 42);
-        PIKA_TEST_EQ(calls.load(), std::size_t(1));
-
-        bool exception_thrown = false;
-        try
-        {
-            tt::sync_wait(sf);
-            PIKA_TEST(false);
-        }
-        catch (...)
-        {
-            exception_thrown = true;
-        }
-        PIKA_TEST(exception_thrown);
-    }
-
-    // senders as futures
-    {
-        auto s = ex::just(3);
-        auto f = ex::make_future(std::move(s));
-        PIKA_TEST_EQ(f.get(), 3);
-    }
-
-    {
-        auto s = ex::transfer_just(ex::thread_pool_scheduler{}, 3);
-        auto f = ex::make_future(std::move(s));
-        PIKA_TEST_EQ(f.get(), 3);
-    }
-
-    {
-        auto f = ex::just(3) | ex::make_future();
-        PIKA_TEST_EQ(f.get(), 3);
-    }
-
-    {
-        auto f = ex::transfer_just(ex::thread_pool_scheduler{}, 3) | ex::make_future();
-        PIKA_TEST_EQ(f.get(), 3);
-    }
-
-    {
-        std::atomic<bool> called{false};
-        auto s = ex::schedule(ex::thread_pool_scheduler{}) | ex::then([&] { called = true; });
-        auto f = ex::make_future(std::move(s));
-        f.get();
-        PIKA_TEST(called);
-    }
-
-    {
-        auto s1 = ex::transfer_just(ex::thread_pool_scheduler{}, std::size_t(42));
-        auto s2 = ex::transfer_just(ex::thread_pool_scheduler{}, 3.14);
-        auto s3 = ex::transfer_just(ex::thread_pool_scheduler{}, std::string("hello"));
-        auto f = ex::make_future(ex::then(ex::when_all(std::move(s1), std::move(s2), std::move(s3)),
-            [](std::size_t x, double, std::string z) { return z.size() + x; }));
-        PIKA_TEST_EQ(f.get(), std::size_t(47));
-    }
-
-    // mixing senders and futures
-    {
-        PIKA_TEST_EQ(
-            tt::sync_wait(ex::make_future(ex::transfer_just(ex::thread_pool_scheduler{}, 42))), 42);
-    }
-
-    {
-        PIKA_TEST_EQ(ex::make_future(ex::transfer(pika::async([]() { return 42; }),
-                                         ex::thread_pool_scheduler{}))
-                         .get(),
-            42);
-    }
-
-    {
-        auto s1 = ex::transfer_just(ex::thread_pool_scheduler{}, std::size_t(42));
-        auto s2 = ex::transfer_just(ex::thread_pool_scheduler{}, 3.14);
-        auto s3 = ex::transfer_just(ex::thread_pool_scheduler{}, std::string("hello"));
-        auto f = ex::make_future(ex::then(ex::when_all(std::move(s1), std::move(s2), std::move(s3)),
-            [](std::size_t x, double, std::string z) { return z.size() + x; }));
-        auto sf = f.then([](auto&& f) { return f.get() - 40; }).share();
-        auto t1 = sf.then([](auto&& sf) { return sf.get() + 1; });
-        auto t2 = sf.then([](auto&& sf) { return sf.get() + 2; });
-        auto t1s = ex::then(std::move(t1), [](std::size_t x) { return x + 1; });
-        auto t1f = ex::make_future(std::move(t1s));
-        auto last = pika::dataflow(
-            pika::unwrapping([](std::size_t x, std::size_t y) { return x + y; }), t1f, t2);
-
-        PIKA_TEST_EQ(last.get(), std::size_t(18));
-    }
-}
-
 void test_ensure_started()
 {
     ex::thread_pool_scheduler sched{};
@@ -1401,210 +1209,6 @@ void test_detach()
     }
 }
 
-void test_keep_future_sender()
-{
-    // the future should be passed to then, not it's contained value
-    {
-        tt::sync_wait(pika::make_ready_future<void>() | ex::keep_future() |
-            ex::then([](pika::future<void>&& f) { PIKA_TEST(f.is_ready()); }));
-    }
-
-    {
-        tt::sync_wait(pika::make_ready_future<void>().share() | ex::keep_future() |
-            ex::then([](pika::shared_future<void>&& f) { PIKA_TEST(f.is_ready()); }));
-    }
-
-    {
-        tt::sync_wait(pika::make_ready_future<int>(42) | ex::keep_future() |
-            ex::then([](pika::future<int>&& f) {
-                PIKA_TEST(f.is_ready());
-                PIKA_TEST_EQ(f.get(), 42);
-            }));
-    }
-
-    {
-        tt::sync_wait(pika::make_ready_future<int>(42).share() | ex::keep_future() |
-            ex::then([](pika::shared_future<int>&& f) {
-                PIKA_TEST(f.is_ready());
-                PIKA_TEST_EQ(f.get(), 42);
-            }));
-    }
-
-    {
-        std::atomic<bool> called{false};
-        auto f = pika::async([&]() { called = true; });
-
-        auto r = tt::sync_wait(std::move(f) | ex::keep_future());
-        static_assert(std::is_same<std::decay_t<decltype(r)>, pika::future<void>>::value,
-            "sync_wait should return future<void>");
-
-        PIKA_TEST(called);
-        PIKA_TEST(r.is_ready());
-
-        bool exception_thrown = false;
-        try
-        {
-            // The move is intentional. sync_wait should throw.
-            // NOLINTNEXTLINE(bugprone-use-after-move)
-            tt::sync_wait(std::move(f) | ex::keep_future());
-            PIKA_TEST(false);
-        }
-        catch (...)
-        {
-            exception_thrown = true;
-        }
-        PIKA_TEST(exception_thrown);
-    }
-
-    {
-        std::atomic<bool> called{false};
-        auto f = pika::async([&]() {
-            called = true;
-            return 42;
-        });
-
-        auto r = tt::sync_wait(std::move(f) | ex::keep_future());
-        static_assert(std::is_same<std::decay_t<decltype(r)>, pika::future<int>>::value,
-            "sync_wait should return future<int>");
-
-        PIKA_TEST(called);
-        PIKA_TEST(r.is_ready());
-        PIKA_TEST_EQ(r.get(), 42);
-
-        bool exception_thrown = false;
-        try
-        {
-            // The move is intentional. sync_wait should throw.
-            // NOLINTNEXTLINE(bugprone-use-after-move)
-            tt::sync_wait(std::move(f) | ex::keep_future());
-            PIKA_TEST(false);
-        }
-        catch (...)
-        {
-            exception_thrown = true;
-        }
-        PIKA_TEST(exception_thrown);
-    }
-
-    {
-        std::atomic<bool> called{false};
-        auto f = pika::async([&]() {
-            called = true;
-            return 42;
-        });
-
-        PIKA_TEST_EQ(tt::sync_wait(ex::then(std::move(f) | ex::keep_future(),
-                         [](pika::future<int>&& f) { return f.get() / 2; })),
-            21);
-        PIKA_TEST(called);
-    }
-
-    {
-        std::atomic<std::size_t> calls{0};
-        auto sf = pika::async([&]() { ++calls; }).share();
-
-        tt::sync_wait(sf | ex::keep_future());
-        tt::sync_wait(sf | ex::keep_future());
-        tt::sync_wait(std::move(sf) | ex::keep_future());
-        PIKA_TEST_EQ(calls.load(), std::size_t(1));
-
-        bool exception_thrown = false;
-        try
-        {
-            tt::sync_wait(sf | ex::keep_future());
-            PIKA_TEST(false);
-        }
-        catch (...)
-        {
-            exception_thrown = true;
-        }
-        PIKA_TEST(exception_thrown);
-    }
-
-    {
-        std::atomic<std::size_t> calls{0};
-        auto sf = pika::async([&]() {
-            ++calls;
-            return 42;
-        }).share();
-
-        PIKA_TEST_EQ(tt::sync_wait(sf | ex::keep_future()).get(), 42);
-        PIKA_TEST_EQ(tt::sync_wait(sf | ex::keep_future()).get(), 42);
-        PIKA_TEST_EQ(tt::sync_wait(std::move(sf) | ex::keep_future()).get(), 42);
-        PIKA_TEST_EQ(calls.load(), std::size_t(1));
-
-        bool exception_thrown = false;
-        try
-        {
-            tt::sync_wait(sf | ex::keep_future());
-            PIKA_TEST(false);
-        }
-        catch (...)
-        {
-            exception_thrown = true;
-        }
-        PIKA_TEST(exception_thrown);
-    }
-
-    // Keep future alive across on
-    {
-        auto f = pika::async([&]() { return 42; });
-
-        auto r = tt::sync_wait(
-            std::move(f) | ex::keep_future() | ex::transfer(ex::thread_pool_scheduler{}));
-        PIKA_TEST(r.is_ready());
-        PIKA_TEST_EQ(r.get(), 42);
-    }
-
-    {
-        auto sf = pika::async([&]() { return 42; }).share();
-
-        auto r = tt::sync_wait(
-            std::move(sf) | ex::keep_future() | ex::transfer(ex::thread_pool_scheduler{}));
-        PIKA_TEST(r.is_ready());
-        PIKA_TEST_EQ(r.get(), 42);
-    }
-
-    {
-        auto sf = pika::async([&]() {
-            return custom_type_non_default_constructible_non_copyable{42};
-        }).share();
-
-        // NOTE: Without keep_future this should fail to compile, since
-        // sync_wait would receive a const& to the value which requires a copy
-        // or storing a const&. The copy is not possible because the type is
-        // noncopyable, and storing a reference is not acceptable since the
-        // reference may outlive the value.
-        auto r = tt::sync_wait(
-            std::move(sf) | ex::keep_future() | ex::transfer(ex::thread_pool_scheduler{}));
-        PIKA_TEST(r.is_ready());
-        PIKA_TEST_EQ(r.get().x, 42);
-    }
-
-    // Use unwrapping with keep_future
-    {
-        auto f = pika::async([]() { return 42; });
-        auto sf = pika::async([]() { return 3.14; }).share();
-
-        auto fun = pika::unwrapping([](int&& x, double const& y) { return x * 2 + (int(y) / 2); });
-        PIKA_TEST_EQ(
-            tt::sync_wait(ex::when_all(std::move(f) | ex::keep_future(), sf | ex::keep_future()) |
-                ex::then(fun)),
-            85);
-    }
-
-    {
-        auto f = pika::async([]() { return 42; });
-        auto sf = pika::async([]() { return 3.14; }).share();
-
-        auto fun = pika::unwrapping([](int&& x, double const& y) { return x * 2 + (int(y) / 2); });
-        PIKA_TEST_EQ(
-            tt::sync_wait(ex::when_all(std::move(f) | ex::keep_future(), sf | ex::keep_future()) |
-                ex::transfer(ex::thread_pool_scheduler{}) | ex::then(fun)),
-            85);
-    }
-}
-
 void test_bulk()
 {
     std::vector<int> const ns = {0, 1, 10, 43};
@@ -1891,8 +1495,6 @@ int pika_main()
     test_transfer_just_two_args();
     test_when_all();
     test_when_all_vector();
-    test_future_sender();
-    test_keep_future_sender();
     test_ensure_started();
     test_ensure_started_when_all();
     test_split();
@@ -1906,7 +1508,8 @@ int pika_main()
     test_completion_scheduler();
     test_scheduler_queries();
 
-    return pika::finalize();
+    pika::finalize();
+    return EXIT_SUCCESS;
 }
 
 int main(int argc, char* argv[])
