@@ -18,34 +18,19 @@ namespace pika::detail::filesystem {
         return ip;
     }
 
-    std::string basename(std::filesystem::path const& p)
-    {
-        return p.stem().string();
-    }
+    std::string basename(std::filesystem::path const& p) { return p.stem().string(); }
 
     std::filesystem::path canonical(
         std::filesystem::path const& p, std::filesystem::path const& base)
     {
-        if (p.is_relative())
-        {
-            return canonical(base / p);
-        }
-        else
-        {
-            return canonical(p);
-        }
+        if (p.is_relative()) { return canonical(base / p); }
+        else { return canonical(p); }
     }
 
     std::filesystem::path canonical(
         std::filesystem::path const& p, std::filesystem::path const& base, std::error_code& ec)
     {
-        if (p.is_relative())
-        {
-            return canonical(base / p, ec);
-        }
-        else
-        {
-            return canonical(p, ec);
-        }
+        if (p.is_relative()) { return canonical(base / p, ec); }
+        else { return canonical(p, ec); }
     }
 }    // namespace pika::detail::filesystem
