@@ -17,8 +17,7 @@ namespace po = pika::program_options;
 std::vector<std::string> sv(const char* array[], unsigned size)
 {
     std::vector<std::string> r;
-    for (unsigned i = 0; i < size; ++i)
-        r.emplace_back(array[i]);
+    for (unsigned i = 0; i < size; ++i) r.emplace_back(array[i]);
     return r;
 }
 
