@@ -15,8 +15,7 @@
 
 namespace pika {
     /// The function report_error reports the given exception to the console
-    PIKA_EXPORT void report_error(
-        std::size_t num_thread, std::exception_ptr const& e);
+    PIKA_EXPORT void report_error(std::size_t num_thread, std::exception_ptr const& e);
 
     /// The function report_error reports the given exception to the console
     PIKA_EXPORT void report_error(std::exception_ptr const& e);
