@@ -37,11 +37,16 @@
 #include <pika/topology/topology.hpp>
 #include <pika/version.hpp>
 
+#if defined(PIKA_HAVE_MPI)
+# include <pika/mpi_base/mpi.hpp>
+#endif
+
 #if defined(PIKA_HAVE_TRACY)
 # include <common/TracySystem.hpp>
 #endif
 
-#include <fmt/format.h>
+#include <fmt/ostream.h>
+#include <fmt/printf.h>
 
 #include <atomic>
 #include <chrono>
@@ -475,28 +480,12 @@ namespace pika {
         return newf;
     }
 
-    std::uint32_t runtime::get_locality_id(error_code& /* ec */) const { return 0; }
-
     std::size_t runtime::get_num_worker_threads() const
     {
         PIKA_ASSERT(thread_manager_);
         return thread_manager_->get_os_thread_count();
     }
 
-    std::uint32_t runtime::get_num_localities(pika::launch::sync_policy, error_code& /* ec */) const
-    {
-        return 1;
-    }
-
-    std::uint32_t runtime::get_initial_num_localities() const { return 1; }
-
-    pika::future<std::uint32_t> runtime::get_num_localities() const
-    {
-        return make_ready_future(std::uint32_t(1));
-    }
-
-    std::string runtime::get_locality_name() const { return "console"; }
-
     ///////////////////////////////////////////////////////////////////////////
     threads::callback_notifier::on_startstop_type get_thread_on_start_func()
     {
@@ -701,8 +690,8 @@ namespace pika {
 
     namespace detail {
         ///////////////////////////////////////////////////////////////////////////
-        // retrieve the command line arguments for the current locality
-        bool retrieve_commandline_arguments(
+        // retrieve the command line arguments
+        void retrieve_commandline_arguments(
             pika::program_options::options_description const& app_options,
             pika::program_options::variables_map& vm)
         {
@@ -717,20 +706,20 @@ namespace pika {
             pika::detail::section& cfg = pika::get_runtime().get_config();
             if (cfg.has_entry("pika.cmd_line")) cmdline = cfg.get_entry("pika.cmd_line");
 
-            return parse_commandline(
+            parse_commandline(
                 cfg, app_options, cmdline, vm, commandline_error_mode::allow_unregistered);
         }
 
         ///////////////////////////////////////////////////////////////////////////
-        // retrieve the command line arguments for the current locality
-        bool retrieve_commandline_arguments(
+        // retrieve the command line arguments
+        void retrieve_commandline_arguments(
             std::string const& appname, pika::program_options::variables_map& vm)
         {
             using pika::program_options::options_description;
 
             options_description desc_commandline("Usage: " + appname + " [options]");
 
-            return retrieve_commandline_arguments(desc_commandline, vm);
+            retrieve_commandline_arguments(desc_commandline, vm);
         }
     }    // namespace detail
 
@@ -864,15 +853,6 @@ namespace pika {
     std::uint64_t get_system_uptime() { return runtime::get_system_uptime(); }
 
     pika::util::runtime_configuration const& get_config() { return get_runtime().get_config(); }
-
-    ///////////////////////////////////////////////////////////////////////////
-    /// Return true if networking is enabled.
-    bool is_networking_enabled()
-    {
-        runtime* rt = get_runtime_ptr();
-        if (nullptr != rt) { return rt->is_networking_enabled(); }
-        return true;    // be on the safe side, enable networking
-    }
 }    // namespace pika
 
 #if defined(_WIN64) && defined(PIKA_DEBUG) && !defined(PIKA_HAVE_FIBER_BASED_COROUTINES)
@@ -993,7 +973,19 @@ namespace pika {
                 std::ostringstream strm;
 
                 strm << std::string(79, '*') << '\n';
-                strm << "locality: " << pika::get_locality_id() << '\n';
+
+#if defined(PIKA_HAVE_MPI)
+                int mpi_initialized = 0;
+                if (MPI_Initialized(&mpi_initialized) == MPI_SUCCESS && mpi_initialized)
+                {
+                    int rank = 0;
+                    if (MPI_Comm_rank(MPI_COMM_WORLD, &rank) == MPI_SUCCESS)
+                    {
+                        strm << "MPI rank: " << rank << '\n';
+                    }
+                }
+#endif
+
                 for (std::size_t i = 0; i != num_threads; ++i)
                 {
                     // print the mask for the current PU
@@ -1025,9 +1017,9 @@ namespace pika {
                         std::string boundcpu_str = threads::detail::to_string(boundcpu_never_empty);
                         std::string pu_mask_str = threads::detail::to_string(pu_mask_never_empty);
                         PIKA_THROW_EXCEPTION(pika::error::invalid_status, "handle_print_bind",
-                            "unexpected mismatch between locality {}: binding reported from "
-                            "HWLOC({}) and pika({}) on thread {}",
-                            pika::get_locality_id(), boundcpu_str, pu_mask_str, i);
+                            "unexpected mismatch between binding reported from HWLOC({}) and "
+                            "pika({}) on thread {}",
+                            boundcpu_str, pu_mask_str, i);
                     }
                 }
 
@@ -1100,7 +1092,19 @@ namespace pika {
         if (caught_exception)
         {
             PIKA_ASSERT(exception_);
+
+            // Always report the exception early in case the runtime becomes deadlocked because of the
+            // thrown exception and isn't able to shut down.
+            fmt::print(std::cerr,
+                "The pika runtime caught the following exception in the entry point (typically "
+                "pika_main). The exception may be rethrown later by pika::init or pika::stop. The "
+                "pika runtime will wait for all tasks to finish, but may be deadlocked because of "
+                "the exception.\n");
+            detail::report_exception_and_continue(exception_);
+
+            // Then call user-registered error handlers if available.
             report_error(exception_, false);
+
             finalize();    // make sure the application exits
         }
 
@@ -1124,7 +1128,7 @@ namespace pika {
 
         LRT_(info).format("cmd_line: {}", get_config().get_cmd_line());
 
-        lbt_ << "(1st stage) runtime::start: booting locality " << here();
+        lbt_ << "(1st stage) runtime::start";
 
         // Register this thread with the runtime system to allow calling
         // certain pika functionality from the main thread. Also calls
@@ -1314,61 +1318,47 @@ namespace pika {
         cond.notify_all();    // we're done now
     }
 
-    int runtime::suspend()
+    void runtime::suspend()
     {
         LRT_(info).format("runtime: about to suspend runtime");
 
-        if (state_.load() == runtime_state::sleeping) { return 0; }
+        if (state_.load() == runtime_state::sleeping) { return; }
 
         if (state_.load() != runtime_state::running)
         {
             PIKA_THROW_EXCEPTION(pika::error::invalid_status, "runtime::suspend",
                 "Can only suspend runtime from running state");
-            return -1;
         }
 
         thread_manager_->suspend();
 
         set_state(runtime_state::sleeping);
-
-        return 0;
     }
 
-    int runtime::resume()
+    void runtime::resume()
     {
         LRT_(info).format("runtime: about to resume runtime");
 
-        if (state_.load() == runtime_state::running) { return 0; }
+        if (state_.load() == runtime_state::running) { return; }
 
         if (state_.load() != runtime_state::sleeping)
         {
             PIKA_THROW_EXCEPTION(pika::error::invalid_status, "runtime::resume",
                 "Can only resume runtime from suspended state");
-            return -1;
         }
 
         thread_manager_->resume();
 
         set_state(runtime_state::running);
-
-        return 0;
     }
 
-    int runtime::finalize()
-    {
-        notify_finalize();
-        return 0;
-    }
-
-    bool runtime::is_networking_enabled() { return false; }
+    void runtime::finalize() { notify_finalize(); }
 
     pika::threads::detail::thread_manager& runtime::get_thread_manager()
     {
         return *thread_manager_;
     }
 
-    std::string runtime::here() const { return "127.0.0.1"; }
-
     ///////////////////////////////////////////////////////////////////////////
     bool runtime::report_error(
         std::size_t num_thread, std::exception_ptr const& e, bool /*terminate_all*/)
@@ -1636,18 +1626,6 @@ namespace pika {
         return get_runtime().get_notification_policy(prefix, os_thread_type::worker_thread);
     }
 
-    std::uint32_t get_locality_id(error_code& ec)
-    {
-        runtime* rt = get_runtime_ptr();
-        if (nullptr == rt || rt->get_state() == runtime_state::invalid)
-        {
-            // same as naming::invalid_locality_id
-            return ~static_cast<std::uint32_t>(0);
-        }
-
-        return rt->get_locality_id(ec);
-    }
-
     std::size_t get_num_worker_threads()
     {
         runtime* rt = get_runtime_ptr();
@@ -1661,47 +1639,6 @@ namespace pika {
         return rt->get_num_worker_threads();
     }
 
-    /// \brief Return the number of localities which are currently registered
-    ///        for the running application.
-    std::uint32_t get_num_localities(pika::launch::sync_policy, error_code& ec)
-    {
-        runtime* rt = get_runtime_ptr();
-        if (nullptr == rt)
-        {
-            PIKA_THROW_EXCEPTION(pika::error::invalid_status, "pika::get_num_localities",
-                "the runtime system has not been initialized yet");
-            return std::size_t(0);
-        }
-
-        return rt->get_num_localities(pika::launch::sync, ec);
-    }
-
-    std::uint32_t get_initial_num_localities()
-    {
-        runtime* rt = get_runtime_ptr();
-        if (nullptr == rt)
-        {
-            PIKA_THROW_EXCEPTION(pika::error::invalid_status, "pika::get_initial_num_localities",
-                "the runtime system has not been initialized yet");
-            return std::size_t(0);
-        }
-
-        return rt->get_initial_num_localities();
-    }
-
-    pika::future<std::uint32_t> get_num_localities()
-    {
-        runtime* rt = get_runtime_ptr();
-        if (nullptr == rt)
-        {
-            PIKA_THROW_EXCEPTION(pika::error::invalid_status, "pika::get_num_localities",
-                "the runtime system has not been initialized yet");
-            return make_ready_future(std::uint32_t(0));
-        }
-
-        return rt->get_num_localities();
-    }
-
     namespace threads {
         char const* get_stack_size_name(std::ptrdiff_t size)
         {
