@@ -6,14 +6,13 @@
 // accompanying file LICENSE_1_0.txt or copy at
 // http://www.boost.org/LICENSE_1_0.txt)
 
-#include <pika/future.hpp>
 #include <pika/init.hpp>
 #include <pika/shared_mutex.hpp>
+#include <pika/testing.hpp>
 #include <pika/thread.hpp>
 
-#include <pika/testing.hpp>
-
 #include <chrono>
+#include <cstdlib>
 #include <mutex>
 #include <string>
 #include <thread>
@@ -279,7 +278,8 @@ int pika_main()
     test_if_other_thread_has_shared_lock_try_lock_shared_returns_true();
     test_if_other_thread_has_shared_lock_try_lock_upgrade_returns_true();
 
-    return pika::finalize();
+    pika::finalize();
+    return EXIT_SUCCESS;
 }
 
 int main(int argc, char* argv[])
