@@ -10,39 +10,43 @@
 // thread_stacksize::minimal and thread_stacksize::maximal when a thread has been
 // created.
 
+#include <pika/execution.hpp>
 #include <pika/init.hpp>
-
-#include <pika/modules/async.hpp>
 #include <pika/modules/threading_base.hpp>
 #include <pika/testing.hpp>
 
 #include <cstddef>
+#include <cstdlib>
 #include <iostream>
 #include <string>
 #include <vector>
 
+namespace ex = pika::execution::experimental;
+namespace tt = pika::this_thread::experimental;
+
 void test(pika::execution::thread_stacksize stacksize)
 {
-    pika::execution::parallel_executor exec(stacksize);
-    pika::execution::parallel_executor exec_current(pika::execution::thread_stacksize::current);
+    auto sched = ex::with_stacksize(ex::thread_pool_scheduler{}, stacksize);
+    auto sched_current =
+        ex::with_stacksize(ex::thread_pool_scheduler{}, pika::execution::thread_stacksize::current);
 
-    pika::async(exec, [&exec_current, stacksize]() {
+    tt::sync_wait(ex::schedule(sched) | ex::then([&sched_current, stacksize]() {
         // This thread should have the stack size stacksize; it has been
-        // explicitly set in the executor.
+        // explicitly set in the scheduler.
         pika::execution::thread_stacksize self_stacksize =
             pika::threads::detail::get_self_stacksize_enum();
         PIKA_TEST_EQ(self_stacksize, stacksize);
         PIKA_TEST_NEQ(self_stacksize, pika::execution::thread_stacksize::current);
 
-        pika::async(exec_current, [stacksize]() {
+        tt::sync_wait(ex::schedule(sched_current) | ex::then([stacksize]() {
             // This thread should also have the stack size stacksize; it has
             // been inherited size from the parent thread.
             pika::execution::thread_stacksize self_stacksize =
                 pika::threads::detail::get_self_stacksize_enum();
             PIKA_TEST_EQ(self_stacksize, stacksize);
             PIKA_TEST_NEQ(self_stacksize, pika::execution::thread_stacksize::current);
-        }).get();
-    }).get();
+        }));
+    }));
 }
 
 int pika_main()
@@ -55,7 +59,8 @@ int pika_main()
         test(stacksize);
     }
 
-    return pika::finalize();
+    pika::finalize();
+    return EXIT_SUCCESS;
 }
 
 int main(int argc, char** argv)
